import React, { useState } from 'react';
import ReactDOM from 'react-dom';
import { useUSAtlas } from './useUSAtlas';
import { useData } from './useData';
import { BubbleMap } from './BubbleMap/index.js';
import { DateHistogram } from './DateHistogram/index.js';

const width = 960;
const height = 500;
const dateHistogramSize = 0.13;
const xValue = d => d.dateCollected;
const yValue = d => d.AQI;

const App = () => {
  const USAtlas = useUSAtlas();
  const data = useData();
  const [brushExtent, setBrushExtent] = useState();

  if (!USAtlas || !data) {
    return <pre>Loading...</pre>;
  }
  
  
  const filteredData = brushExtent ? data.filter(d => {
    const date = xValue(d);
    return date > brushExtent[0] && date < brushExtent[1];
  }) : data;

  return (
    <svg width={width} height={height}>
      <BubbleMap data={data} filteredData={filteredData} USAtlas={USAtlas}/>
      <g transform={`translate(0, ${dateHistogramSize / height})`}>
        <DateHistogram 
          data={data}
          filteredData={filteredData}
          height={dateHistogramSize * height}
          width={width}
          setBrushExtent={setBrushExtent}
          xValue={xValue}
          yValue={yValue}
          />
      </g>
    </svg>
  );
};
const rootElement = document.getElementById('root');
ReactDOM.render(<App />, rootElement);
